@@ -32,6 +32,8 @@ class FernetStringField(models.BinaryField):
 
 class HousingStatCreds(models.Model):
     id = models.UUIDField(primary_key=True, default=uuid.uuid4, editable=False)
-    owner = models.CharField(max_length=255, unique=True)
+    owner = models.CharField(max_length=255)
+    group = models.IntegerField()
     username = models.CharField(max_length=255)
     password = FernetStringField()
+    municipality = models.IntegerField()
